@@ -16,6 +16,7 @@ sub app { shift->{app} }
 
 sub build {
     my ($self, %args) = @_;
+    croak 'Dummy method';
 }
 
 sub register {
@@ -80,4 +81,13 @@ Registers one or many methods into the application.
 
     $self->register(hello => sub { print 'Hello!' });
 
+=head1 AUTHOR
+
+Artur Khabibullin - rtkh E<lt>atE<gt> cpan.org
+
+=head1 LICENSE
+
+This module and all the modules in this package are governed by the same license
+as Perl itself.
+
 =cut
